.. _installation:

Installation
============

Kadabra is a library available through the `Python package index (pip)
<https://pypi.python.org/pypi/pip>`_. Installation is simple::

    $ sudo pip install Kadabra

I recommend you use `virtualenv <https://virtualenv.pypa.io/en/latest/>`_ to
isolate your installs to specific development environments and avoid installing
libraries system-wide.

Once you've installed Kadabra (ideally in a virtualenv), you're ready to head
to the :doc:`gettingstarted` section.
